﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;

namespace ELTE.Windows.Students.ViewModel
{
    /// <summary>
    /// Hallgató típusa.
    /// </summary>
    public class Student : INotifyPropertyChanged
    {
        /// <summary>
        /// Azonosító lekérdezése vagy beállítása.
        /// </summary>
        public Int32 Id { get; set; }

        private String _FirstName;
        private String _LastName;
        private String _StudentCode;

        /// <summary>
        /// Keresztnév lekérdezése, vagy beállítása.
        /// </summary>
        public String FirstName
        {
            get { return _FirstName; }
            set
            {
                if (_FirstName != value)
                {
                    _FirstName = value;

                    // Váltáskor kiváltjuk az eseményt
                    RaisePropertyChanged(); 
                    RaisePropertyChanged("FullName");

                }
            }
        }

        /// <summary>
        /// Vezetéknév lekérdezése, vagy beállítása.
        /// </summary>
        public String LastName
        {
            get { return _LastName; }
            set
            {
                if (_LastName != value)
                {
                    _LastName = value;

                    // Váltáskor kiváltjuk az eseményt
                    RaisePropertyChanged();
                    RaisePropertyChanged("FullName");
                }
            }
        }

        /// <summary>
        /// Hallgatói kód lekérdezése, vagy beállítása.
        /// </summary>
        public String StudentCode
        {
            get { return _StudentCode; }
            set
            {
                if (_StudentCode != value)
                {
                    _StudentCode = value;
                    RaisePropertyChanged();
                }
            }
        }

        /// <summary>
        /// Teljes név lekérdezése.
        /// </summary>
        public String FullName
        {
            get { return _FirstName + " " + _LastName; }
        }

        /// <summary>
        /// Tulajdonságváltozás eseménye.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Tulajdonságváltozás eseménykliváltása.
        /// </summary>
        /// <param name="property">A tulajdonság neve.</param>
        private void RaisePropertyChanged([CallerMemberName] String property = "")
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(property));
        }
    }
}
