﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace ELTE.Windows.Students.ViewModel
{
    /// <summary>
    /// Hallgatók megjelenítő típusa.
    /// </summary>
    public class StudentsViewModel : INotifyPropertyChanged
    {
        /// <summary>
        /// Hallgatók gyűjteményének lekérdezése.
        /// </summary>
        public ObservableCollection<Student> Students { get; private set; }

        /// <summary>
        /// Új hallgató lekérdezése.
        /// </summary>
        public Student NewStudent { get; private set; }

        /// <summary>
        /// Új hallgató felvétel parancsának lekérdezése.
        /// </summary>
        public StudentAddCommand AddCommand { get; private set; }

        /// <summary>
        /// Tulajdonságváltozás eseménye.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Hallgatók betöltése.
        /// </summary>
        public void LoadStudents()
        {
            Students = new ObservableCollection<Student>();
            NewStudent = new Student();
            AddCommand = new StudentAddCommand(this); // parancs létrehozása

            Students.Add(new Student { Id = 1, FirstName = "Jelentős", LastName = "János", StudentCode = "JEJSAAI" });
            Students.Add(new Student { Id = 2, FirstName = "Fenenagy", LastName = "Ferenc", StudentCode = "FEFSAAI" });
            Students.Add(new Student { Id = 3, FirstName = "Huba", LastName = "Hugó", StudentCode = "HUHSAAI" });
            Students.Add(new Student { Id = 4, FirstName = "Gem", LastName = "Géza", StudentCode = "GEGSAAI" });
        }

        /// <summary>
        /// Új hallgató felvétele.
        /// </summary>
        public void AddNewStudent()
        {
            Students.Add(NewStudent);
            NewStudent = new Student();
            RaisePropertyChanged("NewStudent");
        }

        /// <summary>
        /// Tulajdonságváltozás eseménykliváltása.
        /// </summary>
        /// <param name="property">A tulajdonság neve.</param>
        private void RaisePropertyChanged(String property)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(property));
        }
    }
}
