﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Windows;
using ELTE.Windows.ThesisGenerator.View;
using ELTE.Windows.ThesisGenerator.ViewModel;

namespace ELTE.Windows.ThesisGenerator
{
    /// <summary>
    /// Alkalmazás típusa.
    /// </summary>
    public partial class App : Application
    {
        private MainWindow _MainWindow;
        private SettingsWindow _SettingsWindow;
        private ThesisGeneratorViewModel _ViewModel;

        /// <summary>
        /// Alkalmazás példányosítása.
        /// </summary>
        public App()
        {
            _ViewModel = new ThesisGeneratorViewModel();
            _ViewModel.ApplicationMessaged += new EventHandler<ApplicationMessageEventArgs>(ViewModel_ApplicationMessaged);
            _ViewModel.OpenSettings += new EventHandler(ViewModel_OpenSettings);

            _MainWindow = new MainWindow();
            _MainWindow.DataContext = _ViewModel;
        }

        /// <summary>
        /// Alkalmazás indításának eseménykezelője.
        /// </summary>
        /// <param name="e">Eseményargumentum.</param>
        protected override void OnStartup(StartupEventArgs e)
        {
            base.OnStartup(e);

            _MainWindow.Show();
        }

        private void ViewModel_ApplicationMessaged(Object sender, ApplicationMessageEventArgs e)
        {
            switch (e.Type) // üzenet megjelenítése a típus függvényében
            {
                case MessageType.Information:
                    MessageBox.Show(e.Message, "Tétel generátor", MessageBoxButton.OK, MessageBoxImage.Information);
                    break;
                case MessageType.Error:
                    MessageBox.Show(e.Message, "Tétel generátor", MessageBoxButton.OK, MessageBoxImage.Error);
                    break;
            }
        }

        private void ViewModel_OpenSettings(Object sender, EventArgs e)
        {
            _SettingsWindow = new SettingsWindow(); // beállítások ablak létrehozása
            _SettingsWindow.DataContext = _ViewModel;
            _SettingsWindow.ShowDialog();
        }
    }
}
